API documentation
=================

.. automodule:: upoints
   :show-inheritance:
   :synopsis: Modules for working with points on Earth

Contents
--------

.. toctree::
   :maxdepth: 2

   baken
   cellid
   cities
   edist
   geonames
   gpx
   kml
   nmea
   osm
   point
   trigpoints
   tzdata
   utils
   weather_stations
   xearth
